import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:payment_lib/payment_lib.dart';
import 'package:payment_lib/src/payment_summary/bill_detail.dart';
import 'package:payment_lib/src/payment_summary/deadline.dart';
import 'package:payment_lib/src/payment_summary/payment_detail.dart';

class PaymentSummaryTypeOne extends StatelessWidget {
  const PaymentSummaryTypeOne({
    Key? key,
    required this.paymentSummaryModel,
    this.paymentDetail = false,
    this.onTapPaymentDetail,
    this.onTapMyOrder,
    this.buttonColor,
    this.btnTextColor,
    this.borderColor,
  }) : super(key: key);

  final dynamic paymentSummaryModel;
  final bool paymentDetail;
  final Function()? onTapPaymentDetail;
  final Function()? onTapMyOrder;
  final Color? buttonColor;
  final Color? btnTextColor;
  final Color? borderColor;

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          DeadlineCard(
            deadline: paymentSummaryModel.deadline,
            endTimeRemaining: DateTime.now().add(
              const Duration(hours: 24),
            ),
          ),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 15),
            child: Text(
                Get.locale == null
                    ? 'Transfer ke'
                    : Get.locale == const Locale('id')
                        ? 'Transfer ke'
                        : 'Transfer to',
                style: Theme.of(context)
                    .textTheme
                    .subtitle2!
                    .copyWith(fontWeight: FontWeight.bold)),
          ),
          BillDetailsCard(
            type: paymentSummaryModel.paymentType,
            imageUrl: paymentSummaryModel.id,
            invoiceNumber: paymentSummaryModel.invoiceNumber,
            paymentName: paymentSummaryModel.bankName,
            virtualAccountNumber: paymentSummaryModel
                .howToPay.virtualAccountInfo.virtualAccountNumber,
            billTotal: paymentSummaryModel.totalBill,
          ),
          if (paymentDetail)
            PaymentDetailCard(
              onTap: onTapPaymentDetail,
            ),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 15),
            child: Text(
              Get.locale == null
                  ? 'Cara Pembayaran'
                  : Get.locale == const Locale('id')
                      ? 'Cara Pembayaran'
                      : 'Payment Instruction',
              style: Theme.of(context)
                  .textTheme
                  .subtitle2!
                  .copyWith(fontWeight: FontWeight.bold),
            ),
          ),
          PaymentInstructionCard(
            paymentIntruction: paymentSummaryModel.howToPay.paymentIntructions,
          ),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 20),
            child: ElevatedButton(
                style: ElevatedButton.styleFrom(
                  shape: RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(10),
                      side: const BorderSide(color: Colors.transparent)),
                  minimumSize: const Size(double.infinity, 40),
                  primary: buttonColor,
                ),
                onPressed: onTapMyOrder,
                child: Text(
                  Get.locale == null
                      ? 'Periksa pesanan saya'
                      : Get.locale == const Locale('id')
                          ? 'Periksa pesanan saya'
                          : 'Check my order',
                  style: Theme.of(context)
                      .textTheme
                      .button!
                      .copyWith(color: btnTextColor),
                )),
          ),
        ],
      ),
    );
  }
}
